<?php declare(strict_types=1);

namespace App\Controller;

use App\Entity\FoodOrder;
use App\Entity\MenuItem;
use App\Entity\OrderItem;
use App\Form\OrderItemType;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use DateTimeImmutable;

#[Route('/order')]
class FoodOrderController extends AbstractController
{
    final public const APP_FOOD_ORDER_SHOW = 'app_food_order_show';

    final public const APP_FOODORDER_ADD_ITEM = 'app_foodorder_add_item';

    final public const APP_FOODORDER_CLOSE = 'app_foodorder_close';

    #[Route('/{id}', name: self::APP_FOOD_ORDER_SHOW, methods: ['GET'])]
    public function show(FoodOrder $foodOrder): Response
    {
        return $this->render(
            'food_order/show.html.twig',
            [
                'food_order' => $foodOrder,
                'menu_items' => $foodOrder->getVendor()->getMenuItems(),
            ],
        );
    }

    #[Route('/close/{id}', name: self::APP_FOODORDER_CLOSE, methods: ['GET'])]
    public function close(
        FoodOrder $foodOrder,
        EntityManagerInterface $entityManager,
    ): Response {
        $foodOrder->setClosedAt();
        $entityManager->persist($foodOrder);
        $entityManager->flush();
        return $this->redirectToRoute(
            self::APP_FOOD_ORDER_SHOW,
            [
                'id' => $foodOrder->getId(),
            ],
            Response::HTTP_SEE_OTHER,
        );
    }

    #[Route(
        '/{foodOrder}/add/{menuItem}',
        name: self::APP_FOODORDER_ADD_ITEM,
        methods: [Request::METHOD_GET, Request::METHOD_POST],
    )]
    public function add(
        FoodOrder $foodOrder,
        MenuItem $menuItem,
        EntityManagerInterface $entityManager,
        Request $request,
    ): Response {
        $orderItem = new OrderItem();
        $orderItem->setFoodOrder($foodOrder);
        $orderItem->setMenuItem($menuItem);

        $form = $this->createForm(OrderItemType::class, $orderItem);
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->persist($orderItem);
            $entityManager->flush();
            return $this->redirectToRoute(
                FoodOrderController::APP_FOOD_ORDER_SHOW,
                [
                    'id' => $foodOrder->getId(),
                ],
                Response::HTTP_SEE_OTHER,
            );
        }

        return $this->render(
            'food_order/orderitem.html.twig',
            [
                'form' => $form,
            ],
        );

    }

    #[Route(
        '/{foodOrder}/remove_item/{orderItem}',
        name: 'app_foodorder_remove_item',
        methods: [Request::METHOD_GET],
    )]
    public function remove(
        FoodOrder $foodOrder,
        OrderItem $orderItem,
        EntityManagerInterface $entityManager,
    ): Response {
        $entityManager->remove($orderItem);
        $entityManager->flush();
        return $this->redirectToRoute(
            self::APP_FOOD_ORDER_SHOW,
            [
                'id' => $foodOrder->getId(),
            ],
            Response::HTTP_SEE_OTHER,
        );
    }
}
