<?php declare(strict_types=1);

namespace App\Controller;

use App\Form\FoodOrderType;
use App\Repository\FoodOrderRepository;
use App\Service\WhoAreYou;
use App\Entity\FoodOrder;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\HttpFoundation\Cookie;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

final class Start extends AbstractController
{
    #[Route('/', name: 'app_index')]
    public function index(
        FoodOrderRepository $foodOrderRepository,
        EntityManagerInterface $em,
        Request $request,
    ): Response {
        $openOrders = $foodOrderRepository->findOpenOrders();
        $order = new FoodOrder();
        $form = $this->createForm(FoodOrderType::class, $order);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em->persist($order);
            $em->flush();
            return $this->redirectToRoute(
                FoodOrderController::APP_FOOD_ORDER_SHOW,
                [
                    'id' => $order->getId(),
                ],
                Response::HTTP_SEE_OTHER,
            );
        }

        return $this->render(
            'start/index.html.twig',
            [
                'orders' => $openOrders,
                'form' => $form,
            ],
        );
    }

    #[Route(
        '/name',
        name: 'app_name',
        methods: [Request::METHOD_GET, Request::METHOD_POST],
    )]
    public function name(Request $request, WhoAreYou $who): Response
    {
        $form = $this
            ->createFormBuilder()
            ->add('name', TextType::class, [
                'data' => $who->username,
            ])
            ->getForm();
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $name = $form->getData()['name'];
            $response = $this->redirectToRoute('app_index');
            $response->headers->setCookie(new Cookie('username', $name));
            return $response;
        }

        return $this->render('start/name.html.twig', [
            'form' => $form->createView(),
        ]);
    }
}
